# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class V1NetworkConnectionGroup(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "agent_connection_group_id": "int",
        "agent_connection_group_updated_at": "datetime",
        "agent_connection_group_status": "V1ConnectionStatus",
        "agent_connection_group_status_reason": "str",
        "agent_connection_group_created_by": "V1ConnectionCreatedBy",
        "agent_1": "NetworkInfoAgentConnectionGroupAgent",
        "agent_2": "NetworkInfoAgentConnectionGroupAgent",
    }

    attribute_map = {
        "agent_connection_group_id": "agent_connection_group_id",
        "agent_connection_group_updated_at": "agent_connection_group_updated_at",
        "agent_connection_group_status": "agent_connection_group_status",
        "agent_connection_group_status_reason": "agent_connection_group_status_reason",
        "agent_connection_group_created_by": "agent_connection_group_created_by",
        "agent_1": "agent_1",
        "agent_2": "agent_2",
    }

    def __init__(
        self,
        agent_connection_group_id=None,
        agent_connection_group_updated_at=None,
        agent_connection_group_status=None,
        agent_connection_group_status_reason=None,
        agent_connection_group_created_by=None,
        agent_1=None,
        agent_2=None,
    ):  # noqa: E501
        """V1NetworkConnectionGroup - a model defined in Swagger"""  # noqa: E501
        self._agent_connection_group_id = None
        self._agent_connection_group_updated_at = None
        self._agent_connection_group_status = None
        self._agent_connection_group_status_reason = None
        self._agent_connection_group_created_by = None
        self._agent_1 = None
        self._agent_2 = None
        self.discriminator = None
        self.agent_connection_group_id = agent_connection_group_id
        self.agent_connection_group_updated_at = agent_connection_group_updated_at
        self.agent_connection_group_status = agent_connection_group_status
        self.agent_connection_group_status_reason = agent_connection_group_status_reason
        self.agent_connection_group_created_by = agent_connection_group_created_by
        self.agent_1 = agent_1
        self.agent_2 = agent_2

    @property
    def agent_connection_group_id(self):
        """Gets the agent_connection_group_id of this V1NetworkConnectionGroup.  # noqa: E501


        :return: The agent_connection_group_id of this V1NetworkConnectionGroup.  # noqa: E501
        :rtype: int
        """
        return self._agent_connection_group_id

    @agent_connection_group_id.setter
    def agent_connection_group_id(self, agent_connection_group_id):
        """Sets the agent_connection_group_id of this V1NetworkConnectionGroup.


        :param agent_connection_group_id: The agent_connection_group_id of this V1NetworkConnectionGroup.  # noqa: E501
        :type: int
        """
        if agent_connection_group_id is None:
            raise ValueError(
                "Invalid value for `agent_connection_group_id`, must not be `None`"
            )  # noqa: E501

        self._agent_connection_group_id = agent_connection_group_id

    @property
    def agent_connection_group_updated_at(self):
        """Gets the agent_connection_group_updated_at of this V1NetworkConnectionGroup.  # noqa: E501


        :return: The agent_connection_group_updated_at of this V1NetworkConnectionGroup.  # noqa: E501
        :rtype: datetime
        """
        return self._agent_connection_group_updated_at

    @agent_connection_group_updated_at.setter
    def agent_connection_group_updated_at(self, agent_connection_group_updated_at):
        """Sets the agent_connection_group_updated_at of this V1NetworkConnectionGroup.


        :param agent_connection_group_updated_at: The agent_connection_group_updated_at of this V1NetworkConnectionGroup.  # noqa: E501
        :type: datetime
        """
        if agent_connection_group_updated_at is None:
            raise ValueError(
                "Invalid value for `agent_connection_group_updated_at`, must not be `None`"
            )  # noqa: E501

        self._agent_connection_group_updated_at = agent_connection_group_updated_at

    @property
    def agent_connection_group_status(self):
        """Gets the agent_connection_group_status of this V1NetworkConnectionGroup.  # noqa: E501


        :return: The agent_connection_group_status of this V1NetworkConnectionGroup.  # noqa: E501
        :rtype: V1ConnectionStatus
        """
        return self._agent_connection_group_status

    @agent_connection_group_status.setter
    def agent_connection_group_status(self, agent_connection_group_status):
        """Sets the agent_connection_group_status of this V1NetworkConnectionGroup.


        :param agent_connection_group_status: The agent_connection_group_status of this V1NetworkConnectionGroup.  # noqa: E501
        :type: V1ConnectionStatus
        """
        if agent_connection_group_status is None:
            raise ValueError(
                "Invalid value for `agent_connection_group_status`, must not be `None`"
            )  # noqa: E501

        self._agent_connection_group_status = agent_connection_group_status

    @property
    def agent_connection_group_status_reason(self):
        """Gets the agent_connection_group_status_reason of this V1NetworkConnectionGroup.  # noqa: E501


        :return: The agent_connection_group_status_reason of this V1NetworkConnectionGroup.  # noqa: E501
        :rtype: str
        """
        return self._agent_connection_group_status_reason

    @agent_connection_group_status_reason.setter
    def agent_connection_group_status_reason(
        self, agent_connection_group_status_reason
    ):
        """Sets the agent_connection_group_status_reason of this V1NetworkConnectionGroup.


        :param agent_connection_group_status_reason: The agent_connection_group_status_reason of this V1NetworkConnectionGroup.  # noqa: E501
        :type: str
        """
        if agent_connection_group_status_reason is None:
            raise ValueError(
                "Invalid value for `agent_connection_group_status_reason`, must not be `None`"
            )  # noqa: E501

        self._agent_connection_group_status_reason = (
            agent_connection_group_status_reason
        )

    @property
    def agent_connection_group_created_by(self):
        """Gets the agent_connection_group_created_by of this V1NetworkConnectionGroup.  # noqa: E501


        :return: The agent_connection_group_created_by of this V1NetworkConnectionGroup.  # noqa: E501
        :rtype: V1ConnectionCreatedBy
        """
        return self._agent_connection_group_created_by

    @agent_connection_group_created_by.setter
    def agent_connection_group_created_by(self, agent_connection_group_created_by):
        """Sets the agent_connection_group_created_by of this V1NetworkConnectionGroup.


        :param agent_connection_group_created_by: The agent_connection_group_created_by of this V1NetworkConnectionGroup.  # noqa: E501
        :type: V1ConnectionCreatedBy
        """
        if agent_connection_group_created_by is None:
            raise ValueError(
                "Invalid value for `agent_connection_group_created_by`, must not be `None`"
            )  # noqa: E501

        self._agent_connection_group_created_by = agent_connection_group_created_by

    @property
    def agent_1(self):
        """Gets the agent_1 of this V1NetworkConnectionGroup.  # noqa: E501


        :return: The agent_1 of this V1NetworkConnectionGroup.  # noqa: E501
        :rtype: NetworkInfoAgentConnectionGroupAgent
        """
        return self._agent_1

    @agent_1.setter
    def agent_1(self, agent_1):
        """Sets the agent_1 of this V1NetworkConnectionGroup.


        :param agent_1: The agent_1 of this V1NetworkConnectionGroup.  # noqa: E501
        :type: NetworkInfoAgentConnectionGroupAgent
        """
        if agent_1 is None:
            raise ValueError(
                "Invalid value for `agent_1`, must not be `None`"
            )  # noqa: E501

        self._agent_1 = agent_1

    @property
    def agent_2(self):
        """Gets the agent_2 of this V1NetworkConnectionGroup.  # noqa: E501


        :return: The agent_2 of this V1NetworkConnectionGroup.  # noqa: E501
        :rtype: NetworkInfoAgentConnectionGroupAgent
        """
        return self._agent_2

    @agent_2.setter
    def agent_2(self, agent_2):
        """Sets the agent_2 of this V1NetworkConnectionGroup.


        :param agent_2: The agent_2 of this V1NetworkConnectionGroup.  # noqa: E501
        :type: NetworkInfoAgentConnectionGroupAgent
        """
        if agent_2 is None:
            raise ValueError(
                "Invalid value for `agent_2`, must not be `None`"
            )  # noqa: E501

        self._agent_2 = agent_2

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1NetworkConnectionGroup, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1NetworkConnectionGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class V1NetworkAuditSearchRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "action": "list[str]",
        "_from": "str",
        "performed_by": "str",
        "skip": "int",
        "source": "list[str]",
        "take": "int",
        "to": "str",
        "type": "list[str]",
    }

    attribute_map = {
        "action": "action",
        "_from": "from",
        "performed_by": "performed_by",
        "skip": "skip",
        "source": "source",
        "take": "take",
        "to": "to",
        "type": "type",
    }

    def __init__(
        self,
        action=None,
        _from=None,
        performed_by=None,
        skip=None,
        source=None,
        take=None,
        to=None,
        type=None,
    ):  # noqa: E501
        """V1NetworkAuditSearchRequest - a model defined in Swagger"""  # noqa: E501
        self._action = None
        self.__from = None
        self._performed_by = None
        self._skip = None
        self._source = None
        self._take = None
        self._to = None
        self._type = None
        self.discriminator = None
        if action is not None:
            self.action = action
        self._from = _from
        if performed_by is not None:
            self.performed_by = performed_by
        if skip is not None:
            self.skip = skip
        if source is not None:
            self.source = source
        if take is not None:
            self.take = take
        self.to = to
        if type is not None:
            self.type = type

    @property
    def action(self):
        """Gets the action of this V1NetworkAuditSearchRequest.  # noqa: E501


        :return: The action of this V1NetworkAuditSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this V1NetworkAuditSearchRequest.


        :param action: The action of this V1NetworkAuditSearchRequest.  # noqa: E501
        :type: list[str]
        """
        allowed_values = [
            "ACTION_CREATED",
            "ACTION_DELETED",
            "ACTION_UPDATED",
        ]  # noqa: E501
        if not set(action).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `action` [{0}], must be a subset of [{1}]".format(  # noqa: E501
                    ", ".join(
                        map(str, set(action) - set(allowed_values))
                    ),  # noqa: E501
                    ", ".join(map(str, allowed_values)),
                )
            )

        self._action = action

    @property
    def _from(self):
        """Gets the _from of this V1NetworkAuditSearchRequest.  # noqa: E501


        :return: The _from of this V1NetworkAuditSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this V1NetworkAuditSearchRequest.


        :param _from: The _from of this V1NetworkAuditSearchRequest.  # noqa: E501
        :type: str
        """
        if _from is None:
            raise ValueError(
                "Invalid value for `_from`, must not be `None`"
            )  # noqa: E501

        self.__from = _from

    @property
    def performed_by(self):
        """Gets the performed_by of this V1NetworkAuditSearchRequest.  # noqa: E501


        :return: The performed_by of this V1NetworkAuditSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._performed_by

    @performed_by.setter
    def performed_by(self, performed_by):
        """Sets the performed_by of this V1NetworkAuditSearchRequest.


        :param performed_by: The performed_by of this V1NetworkAuditSearchRequest.  # noqa: E501
        :type: str
        """

        self._performed_by = performed_by

    @property
    def skip(self):
        """Gets the skip of this V1NetworkAuditSearchRequest.  # noqa: E501


        :return: The skip of this V1NetworkAuditSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._skip

    @skip.setter
    def skip(self, skip):
        """Sets the skip of this V1NetworkAuditSearchRequest.


        :param skip: The skip of this V1NetworkAuditSearchRequest.  # noqa: E501
        :type: int
        """

        self._skip = skip

    @property
    def source(self):
        """Gets the source of this V1NetworkAuditSearchRequest.  # noqa: E501


        :return: The source of this V1NetworkAuditSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this V1NetworkAuditSearchRequest.


        :param source: The source of this V1NetworkAuditSearchRequest.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["SOURCE_USER", "SOURCE_SYSTEM"]  # noqa: E501
        if not set(source).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `source` [{0}], must be a subset of [{1}]".format(  # noqa: E501
                    ", ".join(
                        map(str, set(source) - set(allowed_values))
                    ),  # noqa: E501
                    ", ".join(map(str, allowed_values)),
                )
            )

        self._source = source

    @property
    def take(self):
        """Gets the take of this V1NetworkAuditSearchRequest.  # noqa: E501


        :return: The take of this V1NetworkAuditSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._take

    @take.setter
    def take(self, take):
        """Sets the take of this V1NetworkAuditSearchRequest.


        :param take: The take of this V1NetworkAuditSearchRequest.  # noqa: E501
        :type: int
        """

        self._take = take

    @property
    def to(self):
        """Gets the to of this V1NetworkAuditSearchRequest.  # noqa: E501


        :return: The to of this V1NetworkAuditSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this V1NetworkAuditSearchRequest.


        :param to: The to of this V1NetworkAuditSearchRequest.  # noqa: E501
        :type: str
        """
        if to is None:
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def type(self):
        """Gets the type of this V1NetworkAuditSearchRequest.  # noqa: E501


        :return: The type of this V1NetworkAuditSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this V1NetworkAuditSearchRequest.


        :param type: The type of this V1NetworkAuditSearchRequest.  # noqa: E501
        :type: list[str]
        """
        allowed_values = [
            "TYPE_ACCESS_TOKEN",
            "TYPE_AGENT_TOKEN",
            "TYPE_AGENT",
            "TYPE_CONNECTION",
        ]  # noqa: E501
        if not set(type).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `type` [{0}], must be a subset of [{1}]".format(  # noqa: E501
                    ", ".join(map(str, set(type) - set(allowed_values))),  # noqa: E501
                    ", ".join(map(str, allowed_values)),
                )
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1NetworkAuditSearchRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1NetworkAuditSearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class V1AgentService(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "agent_service_name": "str",
        "agent_service_type": "AgentServiceTypes",
        "agent_service_networks": "list[str]",
        "agent_service_tcp_ports": "list[int]",
        "agent_service_udp_ports": "list[int]",
        "agent_service_is_active": "bool",
        "agent_service_created_at": "datetime",
        "agent_service_subnets": "list[AgentServiceSubnetIdAndIp]",
    }

    attribute_map = {
        "agent_service_name": "agent_service_name",
        "agent_service_type": "agent_service_type",
        "agent_service_networks": "agent_service_networks",
        "agent_service_tcp_ports": "agent_service_tcp_ports",
        "agent_service_udp_ports": "agent_service_udp_ports",
        "agent_service_is_active": "agent_service_is_active",
        "agent_service_created_at": "agent_service_created_at",
        "agent_service_subnets": "agent_service_subnets",
    }

    def __init__(
        self,
        agent_service_name=None,
        agent_service_type=None,
        agent_service_networks=None,
        agent_service_tcp_ports=None,
        agent_service_udp_ports=None,
        agent_service_is_active=None,
        agent_service_created_at=None,
        agent_service_subnets=None,
    ):  # noqa: E501
        """V1AgentService - a model defined in Swagger"""  # noqa: E501
        self._agent_service_name = None
        self._agent_service_type = None
        self._agent_service_networks = None
        self._agent_service_tcp_ports = None
        self._agent_service_udp_ports = None
        self._agent_service_is_active = None
        self._agent_service_created_at = None
        self._agent_service_subnets = None
        self.discriminator = None
        self.agent_service_name = agent_service_name
        self.agent_service_type = agent_service_type
        self.agent_service_networks = agent_service_networks
        self.agent_service_tcp_ports = agent_service_tcp_ports
        self.agent_service_udp_ports = agent_service_udp_ports
        self.agent_service_is_active = agent_service_is_active
        self.agent_service_created_at = agent_service_created_at
        self.agent_service_subnets = agent_service_subnets

    @property
    def agent_service_name(self):
        """Gets the agent_service_name of this V1AgentService.  # noqa: E501


        :return: The agent_service_name of this V1AgentService.  # noqa: E501
        :rtype: str
        """
        return self._agent_service_name

    @agent_service_name.setter
    def agent_service_name(self, agent_service_name):
        """Sets the agent_service_name of this V1AgentService.


        :param agent_service_name: The agent_service_name of this V1AgentService.  # noqa: E501
        :type: str
        """
        if agent_service_name is None:
            raise ValueError(
                "Invalid value for `agent_service_name`, must not be `None`"
            )  # noqa: E501

        self._agent_service_name = agent_service_name

    @property
    def agent_service_type(self):
        """Gets the agent_service_type of this V1AgentService.  # noqa: E501


        :return: The agent_service_type of this V1AgentService.  # noqa: E501
        :rtype: AgentServiceTypes
        """
        return self._agent_service_type

    @agent_service_type.setter
    def agent_service_type(self, agent_service_type):
        """Sets the agent_service_type of this V1AgentService.


        :param agent_service_type: The agent_service_type of this V1AgentService.  # noqa: E501
        :type: AgentServiceTypes
        """
        if agent_service_type is None:
            raise ValueError(
                "Invalid value for `agent_service_type`, must not be `None`"
            )  # noqa: E501

        self._agent_service_type = agent_service_type

    @property
    def agent_service_networks(self):
        """Gets the agent_service_networks of this V1AgentService.  # noqa: E501


        :return: The agent_service_networks of this V1AgentService.  # noqa: E501
        :rtype: list[str]
        """
        return self._agent_service_networks

    @agent_service_networks.setter
    def agent_service_networks(self, agent_service_networks):
        """Sets the agent_service_networks of this V1AgentService.


        :param agent_service_networks: The agent_service_networks of this V1AgentService.  # noqa: E501
        :type: list[str]
        """
        if agent_service_networks is None:
            raise ValueError(
                "Invalid value for `agent_service_networks`, must not be `None`"
            )  # noqa: E501

        self._agent_service_networks = agent_service_networks

    @property
    def agent_service_tcp_ports(self):
        """Gets the agent_service_tcp_ports of this V1AgentService.  # noqa: E501


        :return: The agent_service_tcp_ports of this V1AgentService.  # noqa: E501
        :rtype: list[int]
        """
        return self._agent_service_tcp_ports

    @agent_service_tcp_ports.setter
    def agent_service_tcp_ports(self, agent_service_tcp_ports):
        """Sets the agent_service_tcp_ports of this V1AgentService.


        :param agent_service_tcp_ports: The agent_service_tcp_ports of this V1AgentService.  # noqa: E501
        :type: list[int]
        """
        if agent_service_tcp_ports is None:
            raise ValueError(
                "Invalid value for `agent_service_tcp_ports`, must not be `None`"
            )  # noqa: E501

        self._agent_service_tcp_ports = agent_service_tcp_ports

    @property
    def agent_service_udp_ports(self):
        """Gets the agent_service_udp_ports of this V1AgentService.  # noqa: E501


        :return: The agent_service_udp_ports of this V1AgentService.  # noqa: E501
        :rtype: list[int]
        """
        return self._agent_service_udp_ports

    @agent_service_udp_ports.setter
    def agent_service_udp_ports(self, agent_service_udp_ports):
        """Sets the agent_service_udp_ports of this V1AgentService.


        :param agent_service_udp_ports: The agent_service_udp_ports of this V1AgentService.  # noqa: E501
        :type: list[int]
        """
        if agent_service_udp_ports is None:
            raise ValueError(
                "Invalid value for `agent_service_udp_ports`, must not be `None`"
            )  # noqa: E501

        self._agent_service_udp_ports = agent_service_udp_ports

    @property
    def agent_service_is_active(self):
        """Gets the agent_service_is_active of this V1AgentService.  # noqa: E501


        :return: The agent_service_is_active of this V1AgentService.  # noqa: E501
        :rtype: bool
        """
        return self._agent_service_is_active

    @agent_service_is_active.setter
    def agent_service_is_active(self, agent_service_is_active):
        """Sets the agent_service_is_active of this V1AgentService.


        :param agent_service_is_active: The agent_service_is_active of this V1AgentService.  # noqa: E501
        :type: bool
        """
        if agent_service_is_active is None:
            raise ValueError(
                "Invalid value for `agent_service_is_active`, must not be `None`"
            )  # noqa: E501

        self._agent_service_is_active = agent_service_is_active

    @property
    def agent_service_created_at(self):
        """Gets the agent_service_created_at of this V1AgentService.  # noqa: E501


        :return: The agent_service_created_at of this V1AgentService.  # noqa: E501
        :rtype: datetime
        """
        return self._agent_service_created_at

    @agent_service_created_at.setter
    def agent_service_created_at(self, agent_service_created_at):
        """Sets the agent_service_created_at of this V1AgentService.


        :param agent_service_created_at: The agent_service_created_at of this V1AgentService.  # noqa: E501
        :type: datetime
        """
        if agent_service_created_at is None:
            raise ValueError(
                "Invalid value for `agent_service_created_at`, must not be `None`"
            )  # noqa: E501

        self._agent_service_created_at = agent_service_created_at

    @property
    def agent_service_subnets(self):
        """Gets the agent_service_subnets of this V1AgentService.  # noqa: E501


        :return: The agent_service_subnets of this V1AgentService.  # noqa: E501
        :rtype: list[AgentServiceSubnetIdAndIp]
        """
        return self._agent_service_subnets

    @agent_service_subnets.setter
    def agent_service_subnets(self, agent_service_subnets):
        """Sets the agent_service_subnets of this V1AgentService.


        :param agent_service_subnets: The agent_service_subnets of this V1AgentService.  # noqa: E501
        :type: list[AgentServiceSubnetIdAndIp]
        """
        if agent_service_subnets is None:
            raise ValueError(
                "Invalid value for `agent_service_subnets`, must not be `None`"
            )  # noqa: E501

        self._agent_service_subnets = agent_service_subnets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1AgentService, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1AgentService):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class V1ConnectionAgent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "agent_is_online": "bool",
        "agent_status": "AgentStatus",
        "agent_subnets_count": "int",
        "agent_is_virtual": "bool",
        "agent_name": "str",
        "agent_public_ipv4": "str",
        "agent_id": "int",
        "agent_provider_id": "int",
    }

    attribute_map = {
        "agent_is_online": "agent_is_online",
        "agent_status": "agent_status",
        "agent_subnets_count": "agent_subnets_count",
        "agent_is_virtual": "agent_is_virtual",
        "agent_name": "agent_name",
        "agent_public_ipv4": "agent_public_ipv4",
        "agent_id": "agent_id",
        "agent_provider_id": "agent_provider_id",
    }

    def __init__(
        self,
        agent_is_online=None,
        agent_status=None,
        agent_subnets_count=None,
        agent_is_virtual=None,
        agent_name=None,
        agent_public_ipv4=None,
        agent_id=None,
        agent_provider_id=None,
    ):  # noqa: E501
        """V1ConnectionAgent - a model defined in Swagger"""  # noqa: E501
        self._agent_is_online = None
        self._agent_status = None
        self._agent_subnets_count = None
        self._agent_is_virtual = None
        self._agent_name = None
        self._agent_public_ipv4 = None
        self._agent_id = None
        self._agent_provider_id = None
        self.discriminator = None
        self.agent_is_online = agent_is_online
        self.agent_status = agent_status
        self.agent_subnets_count = agent_subnets_count
        self.agent_is_virtual = agent_is_virtual
        self.agent_name = agent_name
        self.agent_public_ipv4 = agent_public_ipv4
        self.agent_id = agent_id
        self._agent_provider_id = agent_provider_id

    @property
    def agent_is_online(self):
        """Gets the agent_is_online of this V1ConnectionAgent.  # noqa: E501


        :return: The agent_is_online of this V1ConnectionAgent.  # noqa: E501
        :rtype: bool
        """
        return self._agent_is_online

    @agent_is_online.setter
    def agent_is_online(self, agent_is_online):
        """Sets the agent_is_online of this V1ConnectionAgent.


        :param agent_is_online: The agent_is_online of this V1ConnectionAgent.  # noqa: E501
        :type: bool
        """
        if agent_is_online is None:
            raise ValueError(
                "Invalid value for `agent_is_online`, must not be `None`"
            )  # noqa: E501

        self._agent_is_online = agent_is_online

    @property
    def agent_status(self):
        """Gets the agent_status of this V1ConnectionAgent.  # noqa: E501


        :return: The agent_status of this V1ConnectionAgent.  # noqa: E501
        :rtype: AgentStatus
        """
        return self._agent_status

    @agent_status.setter
    def agent_status(self, agent_status):
        """Sets the agent_status of this V1ConnectionAgent.


        :param agent_status: The agent_status of this V1ConnectionAgent.  # noqa: E501
        :type: AgentStatus
        """
        if agent_status is None:
            raise ValueError(
                "Invalid value for `agent_status`, must not be `None`"
            )  # noqa: E501

        self._agent_status = agent_status

    @property
    def agent_subnets_count(self):
        """Gets the agent_subnets_count of this V1ConnectionAgent.  # noqa: E501


        :return: The agent_subnets_count of this V1ConnectionAgent.  # noqa: E501
        :rtype: int
        """
        return self._agent_subnets_count

    @agent_subnets_count.setter
    def agent_subnets_count(self, agent_subnets_count):
        """Sets the agent_subnets_count of this V1ConnectionAgent.


        :param agent_subnets_count: The agent_subnets_count of this V1ConnectionAgent.  # noqa: E501
        :type: int
        """
        if agent_subnets_count is None:
            raise ValueError(
                "Invalid value for `agent_subnets_count`, must not be `None`"
            )  # noqa: E501

        self._agent_subnets_count = agent_subnets_count

    @property
    def agent_is_virtual(self):
        """Gets the agent_is_virtual of this V1ConnectionAgent.  # noqa: E501


        :return: The agent_is_virtual of this V1ConnectionAgent.  # noqa: E501
        :rtype: bool
        """
        return self._agent_is_virtual

    @agent_is_virtual.setter
    def agent_is_virtual(self, agent_is_virtual):
        """Sets the agent_is_virtual of this V1ConnectionAgent.


        :param agent_is_virtual: The agent_is_virtual of this V1ConnectionAgent.  # noqa: E501
        :type: bool
        """
        if agent_is_virtual is None:
            raise ValueError(
                "Invalid value for `agent_is_virtual`, must not be `None`"
            )  # noqa: E501

        self._agent_is_virtual = agent_is_virtual

    @property
    def agent_name(self):
        """Gets the agent_name of this V1ConnectionAgent.  # noqa: E501


        :return: The agent_name of this V1ConnectionAgent.  # noqa: E501
        :rtype: str
        """
        return self._agent_name

    @agent_name.setter
    def agent_name(self, agent_name):
        """Sets the agent_name of this V1ConnectionAgent.


        :param agent_name: The agent_name of this V1ConnectionAgent.  # noqa: E501
        :type: str
        """
        if agent_name is None:
            raise ValueError(
                "Invalid value for `agent_name`, must not be `None`"
            )  # noqa: E501

        self._agent_name = agent_name

    @property
    def agent_public_ipv4(self):
        """Gets the agent_public_ipv4 of this V1ConnectionAgent.  # noqa: E501


        :return: The agent_public_ipv4 of this V1ConnectionAgent.  # noqa: E501
        :rtype: str
        """
        return self._agent_public_ipv4

    @agent_public_ipv4.setter
    def agent_public_ipv4(self, agent_public_ipv4):
        """Sets the agent_public_ipv4 of this V1ConnectionAgent.


        :param agent_public_ipv4: The agent_public_ipv4 of this V1ConnectionAgent.  # noqa: E501
        :type: str
        """
        if agent_public_ipv4 is None:
            raise ValueError(
                "Invalid value for `agent_public_ipv4`, must not be `None`"
            )  # noqa: E501

        self._agent_public_ipv4 = agent_public_ipv4

    @property
    def agent_id(self):
        """Gets the agent_id of this V1ConnectionAgent.  # noqa: E501


        :return: The agent_id of this V1ConnectionAgent.  # noqa: E501
        :rtype: int
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """Sets the agent_id of this V1ConnectionAgent.


        :param agent_id: The agent_id of this V1ConnectionAgent.  # noqa: E501
        :type: int
        """
        if agent_id is None:
            raise ValueError(
                "Invalid value for `agent_id`, must not be `None`"
            )  # noqa: E501

        self._agent_id = agent_id

    @property
    def agent_provider_id(self):
        """Gets the agent_provider_id of this V1ConnectionAgent.  # noqa: E501


        :return: The agent_provider_id of this V1ConnectionAgent.  # noqa: E501
        :rtype: int
        """
        return self._agent_provider_id

    @agent_provider_id.setter
    def agent_provider_id(self, agent_provider_id):
        """Sets the agent_provider_id of this V1ConnectionAgent.


        :param agent_provider_id: The agent_provider_id of this V1ConnectionAgent.  # noqa: E501
        :type: int
        """
        if agent_provider_id is None:
            raise ValueError(
                "Invalid value for `agent_provider_id`, must not be `None`"
            )  # noqa: E501

        self._agent_provider_id = agent_provider_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1ConnectionAgent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ConnectionAgent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from syntropy_sdk.api.agents_api import AgentsApi
from syntropy_sdk.api.analytics_api import AnalyticsApi
from syntropy_sdk.api.audit_api import AuditApi
from syntropy_sdk.api.auth_api import AuthApi
from syntropy_sdk.api.connections_api import ConnectionsApi
from syntropy_sdk.api.network_api import NetworkApi
from syntropy_sdk.api.notification_api import NotificationApi
from syntropy_sdk.api.rules_api import RulesApi
from syntropy_sdk.api.sdn_agents_api import SDNAgentsApi

# import ApiClient
from syntropy_sdk.api_client import ApiClient
from syntropy_sdk.configuration import Configuration

# import models into sdk package
from syntropy_sdk.models.a_data import AData
from syntropy_sdk.models.a_data_response import ADataResponse
from syntropy_sdk.models.access_token_order import AccessTokenOrder
from syntropy_sdk.models.agent_connection_subnet_statuses import (
    AgentConnectionSubnetStatuses,
)
from syntropy_sdk.models.agent_filter_agent_status import AgentFilterAgentStatus
from syntropy_sdk.models.agent_locked_fields import AgentLockedFields
from syntropy_sdk.models.agent_log_labels import AgentLogLabels
from syntropy_sdk.models.agent_log_log import AgentLogLog
from syntropy_sdk.models.agent_log_source import AgentLogSource
from syntropy_sdk.models.agent_provider import AgentProvider
from syntropy_sdk.models.agent_provider_name_and_id import AgentProviderNameAndId
from syntropy_sdk.models.agent_provider_order_string import AgentProviderOrderString
from syntropy_sdk.models.agent_service_subnet_id_and_ip import AgentServiceSubnetIdAndIp
from syntropy_sdk.models.agent_service_types import AgentServiceTypes
from syntropy_sdk.models.agent_services_update_changes import AgentServicesUpdateChanges
from syntropy_sdk.models.agent_status import AgentStatus
from syntropy_sdk.models.agent_tag import AgentTag
from syntropy_sdk.models.agent_type import AgentType
from syntropy_sdk.models.agent_type_param import AgentTypeParam
from syntropy_sdk.models.agent_wg_config import AgentWgConfig
from syntropy_sdk.models.any_of_v1_agent_order_items import AnyOfV1AgentOrderItems
from syntropy_sdk.models.audit_log import AuditLog
from syntropy_sdk.models.auth_source import AuthSource
from syntropy_sdk.models.connections_pointtotag_body import ConnectionsPointtotagBody
from syntropy_sdk.models.coordinates_search_body import CoordinatesSearchBody
from syntropy_sdk.models.default_string import DefaultString
from syntropy_sdk.models.get_user_invitation_response import GetUserInvitationResponse
from syntropy_sdk.models.id_number import IdNumber
from syntropy_sdk.models.ipv4 import Ipv4
from syntropy_sdk.models.latency_diff import LatencyDiff
from syntropy_sdk.models.latency_ratio import LatencyRatio
from syntropy_sdk.models.latitude import Latitude
from syntropy_sdk.models.logs_read_timestamp_entity_type import (
    LogsReadTimestampEntityType,
)
from syntropy_sdk.models.longitude import Longitude
from syntropy_sdk.models.mfa_backup_code import MFABackupCode
from syntropy_sdk.models.mfa_code import MFACode
from syntropy_sdk.models.network_info_agent_connection_group_agent import (
    NetworkInfoAgentConnectionGroupAgent,
)
from syntropy_sdk.models.one_of_v1_connection_order_items import (
    OneOfV1ConnectionOrderItems,
)
from syntropy_sdk.models.one_of_v1_network_agents_settings_update_request import (
    OneOfV1NetworkAgentsSettingsUpdateRequest,
)
from syntropy_sdk.models.order_string import OrderString
from syntropy_sdk.models.permission import Permission
from syntropy_sdk.models.role import Role
from syntropy_sdk.models.skip_number import SkipNumber
from syntropy_sdk.models.take_number import TakeNumber
from syntropy_sdk.models.user import User
from syntropy_sdk.models.user_settings import UserSettings
from syntropy_sdk.models.user_theme import UserTheme
from syntropy_sdk.models.user_with_role import UserWithRole
from syntropy_sdk.models.user_workspace import UserWorkspace
from syntropy_sdk.models.v1_a_agent_pair import V1AAgentPair
from syntropy_sdk.models.v1_a_status import V1AStatus
from syntropy_sdk.models.v1_a_status_agent_status import V1AStatusAgentStatus
from syntropy_sdk.models.v1_a_status_warning import V1AStatusWarning
from syntropy_sdk.models.v1_agent import V1Agent
from syntropy_sdk.models.v1_agent_coordinates import V1AgentCoordinates
from syntropy_sdk.models.v1_agent_create_item import V1AgentCreateItem
from syntropy_sdk.models.v1_agent_error_log import V1AgentErrorLog
from syntropy_sdk.models.v1_agent_error_log_source import V1AgentErrorLogSource
from syntropy_sdk.models.v1_agent_filter import V1AgentFilter
from syntropy_sdk.models.v1_agent_filters import V1AgentFilters
from syntropy_sdk.models.v1_agent_filters_agent_name import V1AgentFiltersAgentName
from syntropy_sdk.models.v1_agent_log import V1AgentLog
from syntropy_sdk.models.v1_agent_log_severity import V1AgentLogSeverity
from syntropy_sdk.models.v1_agent_log_sort import V1AgentLogSort
from syntropy_sdk.models.v1_agent_order import V1AgentOrder
from syntropy_sdk.models.v1_agent_pair_filter import V1AgentPairFilter
from syntropy_sdk.models.v1_agent_service import V1AgentService
from syntropy_sdk.models.v1_agent_settings import V1AgentSettings
from syntropy_sdk.models.v1_agent_settings_rerouting_threshold import (
    V1AgentSettingsReroutingThreshold,
)
from syntropy_sdk.models.v1_agent_tag import V1AgentTag
from syntropy_sdk.models.v1_auth_access_token import V1AuthAccessToken
from syntropy_sdk.models.v1_auth_access_token_login_item import (
    V1AuthAccessTokenLoginItem,
)
from syntropy_sdk.models.v1_auth_access_token_permissions import (
    V1AuthAccessTokenPermissions,
)
from syntropy_sdk.models.v1_auth_access_tokens_create_item import (
    V1AuthAccessTokensCreateItem,
)
from syntropy_sdk.models.v1_auth_api_key import V1AuthApiKey
from syntropy_sdk.models.v1_auth_api_keys_create_item import V1AuthApiKeysCreateItem
from syntropy_sdk.models.v1_auth_mfa_confirm import V1AuthMfaConfirm
from syntropy_sdk.models.v1_auth_mfa_generate import V1AuthMfaGenerate
from syntropy_sdk.models.v1_auth_user import V1AuthUser
from syntropy_sdk.models.v1_connection import V1Connection
from syntropy_sdk.models.v1_connection_agent import V1ConnectionAgent
from syntropy_sdk.models.v1_connection_created_by import V1ConnectionCreatedBy
from syntropy_sdk.models.v1_connection_filter import V1ConnectionFilter
from syntropy_sdk.models.v1_connection_order import V1ConnectionOrder
from syntropy_sdk.models.v1_connection_service import V1ConnectionService
from syntropy_sdk.models.v1_connection_service_agent import V1ConnectionServiceAgent
from syntropy_sdk.models.v1_connection_service_agent_service import (
    V1ConnectionServiceAgentService,
)
from syntropy_sdk.models.v1_connection_service_agent_service_agent_service_subnets import (
    V1ConnectionServiceAgentServiceAgentServiceSubnets,
)
from syntropy_sdk.models.v1_connection_service_subnet import V1ConnectionServiceSubnet
from syntropy_sdk.models.v1_connection_status import V1ConnectionStatus
from syntropy_sdk.models.v1_connection_update_change import V1ConnectionUpdateChange
from syntropy_sdk.models.v1_error_response import V1ErrorResponse
from syntropy_sdk.models.v1_error_response_errors import V1ErrorResponseErrors
from syntropy_sdk.models.v1_network import V1Network
from syntropy_sdk.models.v1_network_a_statuses_search_request import (
    V1NetworkAStatusesSearchRequest,
)
from syntropy_sdk.models.v1_network_a_statuses_search_request_filter import (
    V1NetworkAStatusesSearchRequestFilter,
)
from syntropy_sdk.models.v1_network_a_statuses_search_response import (
    V1NetworkAStatusesSearchResponse,
)
from syntropy_sdk.models.v1_network_a_statuses_warnings_search_request import (
    V1NetworkAStatusesWarningsSearchRequest,
)
from syntropy_sdk.models.v1_network_a_statuses_warnings_search_request_filter import (
    V1NetworkAStatusesWarningsSearchRequestFilter,
)
from syntropy_sdk.models.v1_network_a_statuses_warnings_search_request_order import (
    V1NetworkAStatusesWarningsSearchRequestOrder,
)
from syntropy_sdk.models.v1_network_a_statuses_warnings_search_response import (
    V1NetworkAStatusesWarningsSearchResponse,
)
from syntropy_sdk.models.v1_network_agent import V1NetworkAgent
from syntropy_sdk.models.v1_network_agents_coordinates_search_response import (
    V1NetworkAgentsCoordinatesSearchResponse,
)
from syntropy_sdk.models.v1_network_agents_create_request import (
    V1NetworkAgentsCreateRequest,
)
from syntropy_sdk.models.v1_network_agents_create_response import (
    V1NetworkAgentsCreateResponse,
)
from syntropy_sdk.models.v1_network_agents_filters_search_response import (
    V1NetworkAgentsFiltersSearchResponse,
)
from syntropy_sdk.models.v1_network_agents_get_response import (
    V1NetworkAgentsGetResponse,
)
from syntropy_sdk.models.v1_network_agents_logs_errors_search_request import (
    V1NetworkAgentsLogsErrorsSearchRequest,
)
from syntropy_sdk.models.v1_network_agents_logs_errors_search_response import (
    V1NetworkAgentsLogsErrorsSearchResponse,
)
from syntropy_sdk.models.v1_network_agents_logs_reads_timestamp_search_request import (
    V1NetworkAgentsLogsReadsTimestampSearchRequest,
)
from syntropy_sdk.models.v1_network_agents_logs_search_request import (
    V1NetworkAgentsLogsSearchRequest,
)
from syntropy_sdk.models.v1_network_agents_logs_search_response import (
    V1NetworkAgentsLogsSearchResponse,
)
from syntropy_sdk.models.v1_network_agents_providers_get_response import (
    V1NetworkAgentsProvidersGetResponse,
)
from syntropy_sdk.models.v1_network_agents_remove_request import (
    V1NetworkAgentsRemoveRequest,
)
from syntropy_sdk.models.v1_network_agents_search_request import (
    V1NetworkAgentsSearchRequest,
)
from syntropy_sdk.models.v1_network_agents_search_response import (
    V1NetworkAgentsSearchResponse,
)
from syntropy_sdk.models.v1_network_agents_services_get_response import (
    V1NetworkAgentsServicesGetResponse,
)
from syntropy_sdk.models.v1_network_agents_services_remove_request import (
    V1NetworkAgentsServicesRemoveRequest,
)
from syntropy_sdk.models.v1_network_agents_services_update_request import (
    V1NetworkAgentsServicesUpdateRequest,
)
from syntropy_sdk.models.v1_network_agents_services_update_request_subnets_to_update import (
    V1NetworkAgentsServicesUpdateRequestSubnetsToUpdate,
)
from syntropy_sdk.models.v1_network_agents_settings_get_response import (
    V1NetworkAgentsSettingsGetResponse,
)
from syntropy_sdk.models.v1_network_agents_settings_update_request import (
    V1NetworkAgentsSettingsUpdateRequest,
)
from syntropy_sdk.models.v1_network_agents_tags_get_response import (
    V1NetworkAgentsTagsGetResponse,
)
from syntropy_sdk.models.v1_network_agents_update_request import (
    V1NetworkAgentsUpdateRequest,
)
from syntropy_sdk.models.v1_network_agents_wg_config_get_one_response import (
    V1NetworkAgentsWgConfigGetOneResponse,
)
from syntropy_sdk.models.v1_network_audit_search_request import (
    V1NetworkAuditSearchRequest,
)
from syntropy_sdk.models.v1_network_audit_search_response import (
    V1NetworkAuditSearchResponse,
)
from syntropy_sdk.models.v1_network_auth_access_token_login_request import (
    V1NetworkAuthAccessTokenLoginRequest,
)
from syntropy_sdk.models.v1_network_auth_access_token_login_response import (
    V1NetworkAuthAccessTokenLoginResponse,
)
from syntropy_sdk.models.v1_network_auth_access_tokens_create_request import (
    V1NetworkAuthAccessTokensCreateRequest,
)
from syntropy_sdk.models.v1_network_auth_access_tokens_create_response import (
    V1NetworkAuthAccessTokensCreateResponse,
)
from syntropy_sdk.models.v1_network_auth_access_tokens_get_response import (
    V1NetworkAuthAccessTokensGetResponse,
)
from syntropy_sdk.models.v1_network_auth_access_tokens_permissions_get_response import (
    V1NetworkAuthAccessTokensPermissionsGetResponse,
)
from syntropy_sdk.models.v1_network_auth_api_keys_create_request import (
    V1NetworkAuthApiKeysCreateRequest,
)
from syntropy_sdk.models.v1_network_auth_api_keys_create_response import (
    V1NetworkAuthApiKeysCreateResponse,
)
from syntropy_sdk.models.v1_network_auth_api_keys_get_response import (
    V1NetworkAuthApiKeysGetResponse,
)
from syntropy_sdk.models.v1_network_auth_mfa_confirm_request import (
    V1NetworkAuthMfaConfirmRequest,
)
from syntropy_sdk.models.v1_network_auth_mfa_confirm_response import (
    V1NetworkAuthMfaConfirmResponse,
)
from syntropy_sdk.models.v1_network_auth_mfa_disable_request import (
    V1NetworkAuthMfaDisableRequest,
)
from syntropy_sdk.models.v1_network_auth_mfa_disable_using_backup_request import (
    V1NetworkAuthMfaDisableUsingBackupRequest,
)
from syntropy_sdk.models.v1_network_auth_mfa_generate_response import (
    V1NetworkAuthMfaGenerateResponse,
)
from syntropy_sdk.models.v1_network_auth_user_get_response import (
    V1NetworkAuthUserGetResponse,
)
from syntropy_sdk.models.v1_network_auth_user_invitations_get_response import (
    V1NetworkAuthUserInvitationsGetResponse,
)
from syntropy_sdk.models.v1_network_auth_users_get_response import (
    V1NetworkAuthUsersGetResponse,
)
from syntropy_sdk.models.v1_network_auth_users_remove_request import (
    V1NetworkAuthUsersRemoveRequest,
)
from syntropy_sdk.models.v1_network_auth_users_role_update_request import (
    V1NetworkAuthUsersRoleUpdateRequest,
)
from syntropy_sdk.models.v1_network_auth_workspace_create_request import (
    V1NetworkAuthWorkspaceCreateRequest,
)
from syntropy_sdk.models.v1_network_auth_workspace_create_response import (
    V1NetworkAuthWorkspaceCreateResponse,
)
from syntropy_sdk.models.v1_network_auth_workspace_get_response import (
    V1NetworkAuthWorkspaceGetResponse,
)
from syntropy_sdk.models.v1_network_auth_workspace_update_request import (
    V1NetworkAuthWorkspaceUpdateRequest,
)
from syntropy_sdk.models.v1_network_auth_workspaces_invitations_create_request import (
    V1NetworkAuthWorkspacesInvitationsCreateRequest,
)
from syntropy_sdk.models.v1_network_auth_workspaces_invitations_create_response import (
    V1NetworkAuthWorkspacesInvitationsCreateResponse,
)
from syntropy_sdk.models.v1_network_auth_workspaces_invitations_get_response import (
    V1NetworkAuthWorkspacesInvitationsGetResponse,
)
from syntropy_sdk.models.v1_network_auth_workspaces_invitations_remove_request import (
    V1NetworkAuthWorkspacesInvitationsRemoveRequest,
)
from syntropy_sdk.models.v1_network_connection_group import V1NetworkConnectionGroup
from syntropy_sdk.models.v1_network_connections_create_mesh_request import (
    V1NetworkConnectionsCreateMeshRequest,
)
from syntropy_sdk.models.v1_network_connections_create_mesh_request_agent_ids import (
    V1NetworkConnectionsCreateMeshRequestAgentIds,
)
from syntropy_sdk.models.v1_network_connections_create_p2_p_request import (
    V1NetworkConnectionsCreateP2PRequest,
)
from syntropy_sdk.models.v1_network_connections_create_p2_p_request_agent_pairs import (
    V1NetworkConnectionsCreateP2PRequestAgentPairs,
)
from syntropy_sdk.models.v1_network_connections_get_response import (
    V1NetworkConnectionsGetResponse,
)
from syntropy_sdk.models.v1_network_connections_remove_request import (
    V1NetworkConnectionsRemoveRequest,
)
from syntropy_sdk.models.v1_network_connections_search_request import (
    V1NetworkConnectionsSearchRequest,
)
from syntropy_sdk.models.v1_network_connections_search_response import (
    V1NetworkConnectionsSearchResponse,
)
from syntropy_sdk.models.v1_network_connections_services_get_response import (
    V1NetworkConnectionsServicesGetResponse,
)
from syntropy_sdk.models.v1_network_connections_services_remove_request import (
    V1NetworkConnectionsServicesRemoveRequest,
)
from syntropy_sdk.models.v1_network_connections_services_update_request import (
    V1NetworkConnectionsServicesUpdateRequest,
)
from syntropy_sdk.models.v1_network_connections_update_request import (
    V1NetworkConnectionsUpdateRequest,
)
from syntropy_sdk.models.v1_network_get_response import V1NetworkGetResponse
from syntropy_sdk.models.v1_network_notification_contact_update_request import (
    V1NetworkNotificationContactUpdateRequest,
)
from syntropy_sdk.models.v1_network_rules_connections_point_to_tag_create_response import (
    V1NetworkRulesConnectionsPointToTagCreateResponse,
)
from syntropy_sdk.models.v1_network_rules_connections_point_to_tag_get_one_response import (
    V1NetworkRulesConnectionsPointToTagGetOneResponse,
)
from syntropy_sdk.models.v1_network_rules_connections_point_to_tag_search_request import (
    V1NetworkRulesConnectionsPointToTagSearchRequest,
)
from syntropy_sdk.models.v1_network_rules_connections_point_to_tag_search_response import (
    V1NetworkRulesConnectionsPointToTagSearchResponse,
)
from syntropy_sdk.models.v1_network_rules_search_request import (
    V1NetworkRulesSearchRequest,
)
from syntropy_sdk.models.v1_network_rules_search_request_filter import (
    V1NetworkRulesSearchRequestFilter,
)
from syntropy_sdk.models.v1_network_rules_search_response import (
    V1NetworkRulesSearchResponse,
)
from syntropy_sdk.models.v1_network_sdn_agents_get_response import (
    V1NetworkSdnAgentsGetResponse,
)
from syntropy_sdk.models.v1_rules_point_to_tag import V1RulesPointToTag
from syntropy_sdk.models.v1_rules_point_to_tag_create_item import (
    V1RulesPointToTagCreateItem,
)
from syntropy_sdk.models.v1_rules_point_to_tag_filter import V1RulesPointToTagFilter
from syntropy_sdk.models.v1_rules_search_item import V1RulesSearchItem
from syntropy_sdk.models.v1_sdn_paths import V1SdnPaths
from syntropy_sdk.models.v1_skip_number import V1SkipNumber
from syntropy_sdk.models.v1_take_number import V1TakeNumber
from syntropy_sdk.models.v1_update_agent_routing_settings import (
    V1UpdateAgentRoutingSettings,
)
from syntropy_sdk.models.v1_update_agent_routing_settings_rerouting_threshold import (
    V1UpdateAgentRoutingSettingsReroutingThreshold,
)
from syntropy_sdk.models.v1_update_agent_routing_settings_reset import (
    V1UpdateAgentRoutingSettingsReset,
)
from syntropy_sdk.models.where_string import WhereString
from syntropy_sdk.models.workspace import Workspace
from syntropy_sdk.models.workspace_invitation import WorkspaceInvitation
from syntropy_sdk.models.workspace_invitation_response import (
    WorkspaceInvitationResponse,
)
from syntropy_sdk.models.workspace_name import WorkspaceName
from syntropy_sdk.models.workspace_role_name import WorkspaceRoleName



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AgentLogSource(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "timestamp": "str",
        "message": "str",
        "labels": "AgentLogLabels",
        "log": "AgentLogLog",
    }

    attribute_map = {
        "timestamp": "@timestamp",
        "message": "message",
        "labels": "labels",
        "log": "log",
    }

    def __init__(
        self, timestamp=None, message=None, labels=None, log=None
    ):  # noqa: E501
        """AgentLogSource - a model defined in Swagger"""  # noqa: E501
        self._timestamp = None
        self._message = None
        self._labels = None
        self._log = None
        self.discriminator = None
        if timestamp is not None:
            self.timestamp = timestamp
        if message is not None:
            self.message = message
        if labels is not None:
            self.labels = labels
        if log is not None:
            self.log = log

    @property
    def timestamp(self):
        """Gets the timestamp of this AgentLogSource.  # noqa: E501


        :return: The timestamp of this AgentLogSource.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this AgentLogSource.


        :param timestamp: The timestamp of this AgentLogSource.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    @property
    def message(self):
        """Gets the message of this AgentLogSource.  # noqa: E501


        :return: The message of this AgentLogSource.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this AgentLogSource.


        :param message: The message of this AgentLogSource.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def labels(self):
        """Gets the labels of this AgentLogSource.  # noqa: E501


        :return: The labels of this AgentLogSource.  # noqa: E501
        :rtype: AgentLogLabels
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this AgentLogSource.


        :param labels: The labels of this AgentLogSource.  # noqa: E501
        :type: AgentLogLabels
        """

        self._labels = labels

    @property
    def log(self):
        """Gets the log of this AgentLogSource.  # noqa: E501


        :return: The log of this AgentLogSource.  # noqa: E501
        :rtype: AgentLogLog
        """
        return self._log

    @log.setter
    def log(self, log):
        """Sets the log of this AgentLogSource.


        :param log: The log of this AgentLogSource.  # noqa: E501
        :type: AgentLogLog
        """

        self._log = log

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(AgentLogSource, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentLogSource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AgentLockedFields(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "agent_location_country": "bool",
        "agent_location_city": "bool",
        "agent_location_lat": "bool",
        "agent_location_lon": "bool",
        "agent_provider_name": "bool",
        "agent_tags": "list[str]",
        "agent_name": "bool",
    }

    attribute_map = {
        "agent_location_country": "agent_location_country",
        "agent_location_city": "agent_location_city",
        "agent_location_lat": "agent_location_lat",
        "agent_location_lon": "agent_location_lon",
        "agent_provider_name": "agent_provider_name",
        "agent_tags": "agent_tags",
        "agent_name": "agent_name",
    }

    def __init__(
        self,
        agent_location_country=None,
        agent_location_city=None,
        agent_location_lat=None,
        agent_location_lon=None,
        agent_provider_name=None,
        agent_tags=None,
        agent_name=None,
    ):  # noqa: E501
        """AgentLockedFields - a model defined in Swagger"""  # noqa: E501
        self._agent_location_country = None
        self._agent_location_city = None
        self._agent_location_lat = None
        self._agent_location_lon = None
        self._agent_provider_name = None
        self._agent_tags = None
        self._agent_name = None
        self.discriminator = None
        if agent_location_country is not None:
            self.agent_location_country = agent_location_country
        if agent_location_city is not None:
            self.agent_location_city = agent_location_city
        if agent_location_lat is not None:
            self.agent_location_lat = agent_location_lat
        if agent_location_lon is not None:
            self.agent_location_lon = agent_location_lon
        if agent_provider_name is not None:
            self.agent_provider_name = agent_provider_name
        if agent_tags is not None:
            self.agent_tags = agent_tags
        if agent_name is not None:
            self.agent_name = agent_name

    @property
    def agent_location_country(self):
        """Gets the agent_location_country of this AgentLockedFields.  # noqa: E501


        :return: The agent_location_country of this AgentLockedFields.  # noqa: E501
        :rtype: bool
        """
        return self._agent_location_country

    @agent_location_country.setter
    def agent_location_country(self, agent_location_country):
        """Sets the agent_location_country of this AgentLockedFields.


        :param agent_location_country: The agent_location_country of this AgentLockedFields.  # noqa: E501
        :type: bool
        """

        self._agent_location_country = agent_location_country

    @property
    def agent_location_city(self):
        """Gets the agent_location_city of this AgentLockedFields.  # noqa: E501


        :return: The agent_location_city of this AgentLockedFields.  # noqa: E501
        :rtype: bool
        """
        return self._agent_location_city

    @agent_location_city.setter
    def agent_location_city(self, agent_location_city):
        """Sets the agent_location_city of this AgentLockedFields.


        :param agent_location_city: The agent_location_city of this AgentLockedFields.  # noqa: E501
        :type: bool
        """

        self._agent_location_city = agent_location_city

    @property
    def agent_location_lat(self):
        """Gets the agent_location_lat of this AgentLockedFields.  # noqa: E501


        :return: The agent_location_lat of this AgentLockedFields.  # noqa: E501
        :rtype: bool
        """
        return self._agent_location_lat

    @agent_location_lat.setter
    def agent_location_lat(self, agent_location_lat):
        """Sets the agent_location_lat of this AgentLockedFields.


        :param agent_location_lat: The agent_location_lat of this AgentLockedFields.  # noqa: E501
        :type: bool
        """

        self._agent_location_lat = agent_location_lat

    @property
    def agent_location_lon(self):
        """Gets the agent_location_lon of this AgentLockedFields.  # noqa: E501


        :return: The agent_location_lon of this AgentLockedFields.  # noqa: E501
        :rtype: bool
        """
        return self._agent_location_lon

    @agent_location_lon.setter
    def agent_location_lon(self, agent_location_lon):
        """Sets the agent_location_lon of this AgentLockedFields.


        :param agent_location_lon: The agent_location_lon of this AgentLockedFields.  # noqa: E501
        :type: bool
        """

        self._agent_location_lon = agent_location_lon

    @property
    def agent_provider_name(self):
        """Gets the agent_provider_name of this AgentLockedFields.  # noqa: E501


        :return: The agent_provider_name of this AgentLockedFields.  # noqa: E501
        :rtype: bool
        """
        return self._agent_provider_name

    @agent_provider_name.setter
    def agent_provider_name(self, agent_provider_name):
        """Sets the agent_provider_name of this AgentLockedFields.


        :param agent_provider_name: The agent_provider_name of this AgentLockedFields.  # noqa: E501
        :type: bool
        """

        self._agent_provider_name = agent_provider_name

    @property
    def agent_tags(self):
        """Gets the agent_tags of this AgentLockedFields.  # noqa: E501


        :return: The agent_tags of this AgentLockedFields.  # noqa: E501
        :rtype: list[str]
        """
        return self._agent_tags

    @agent_tags.setter
    def agent_tags(self, agent_tags):
        """Sets the agent_tags of this AgentLockedFields.


        :param agent_tags: The agent_tags of this AgentLockedFields.  # noqa: E501
        :type: list[str]
        """

        self._agent_tags = agent_tags

    @property
    def agent_name(self):
        """Gets the agent_name of this AgentLockedFields.  # noqa: E501


        :return: The agent_name of this AgentLockedFields.  # noqa: E501
        :rtype: bool
        """
        return self._agent_name

    @agent_name.setter
    def agent_name(self, agent_name):
        """Sets the agent_name of this AgentLockedFields.


        :param agent_name: The agent_name of this AgentLockedFields.  # noqa: E501
        :type: bool
        """

        self._agent_name = agent_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(AgentLockedFields, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentLockedFields):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from syntropy_sdk.api_client import ApiClient


class RulesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def rules_connection_point_to_tag_update(self, body, **kwargs):  # noqa: E501
        """Upsert point-to-tag  # noqa: E501

        Simultaneously adds, removes, replaces point-to-tags Rules.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rules_connection_point_to_tag_update(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ConnectionsPointtotagBody] body: Operations list (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.rules_connection_point_to_tag_update_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.rules_connection_point_to_tag_update_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def rules_connection_point_to_tag_update_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Upsert point-to-tag  # noqa: E501

        Simultaneously adds, removes, replaces point-to-tags Rules.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rules_connection_point_to_tag_update_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ConnectionsPointtotagBody] body: Operations list (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method rules_connection_point_to_tag_update" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `rules_connection_point_to_tag_update`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/rules/connections/point-to-tag",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_rules_connections_point_to_tag_create(
        self, body, **kwargs
    ):  # noqa: E501
        """Create point-to-tag  # noqa: E501

        Creates point to tag Rule.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_rules_connections_point_to_tag_create(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1RulesPointToTag body: (required)
        :return: V1NetworkRulesConnectionsPointToTagCreateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_rules_connections_point_to_tag_create_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (
                data
            ) = self.v1_network_rules_connections_point_to_tag_create_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_rules_connections_point_to_tag_create_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Create point-to-tag  # noqa: E501

        Creates point to tag Rule.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_rules_connections_point_to_tag_create_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1RulesPointToTag body: (required)
        :return: V1NetworkRulesConnectionsPointToTagCreateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_rules_connections_point_to_tag_create" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_rules_connections_point_to_tag_create`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/rules/connections/point-to-tag",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkRulesConnectionsPointToTagCreateResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_rules_connections_point_to_tag_get_one(
        self, agent_id, **kwargs
    ):  # noqa: E501
        """Get point-to-tag  # noqa: E501

        Retrieve point-to-tag Rules by `agent_id`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_rules_connections_point_to_tag_get_one(agent_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdNumber agent_id: (required)
        :return: V1NetworkRulesConnectionsPointToTagGetOneResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return (
                self.v1_network_rules_connections_point_to_tag_get_one_with_http_info(
                    agent_id, **kwargs
                )
            )  # noqa: E501
        else:
            (
                data
            ) = self.v1_network_rules_connections_point_to_tag_get_one_with_http_info(
                agent_id, **kwargs
            )  # noqa: E501
            return data

    def v1_network_rules_connections_point_to_tag_get_one_with_http_info(
        self, agent_id, **kwargs
    ):  # noqa: E501
        """Get point-to-tag  # noqa: E501

        Retrieve point-to-tag Rules by `agent_id`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_rules_connections_point_to_tag_get_one_with_http_info(agent_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdNumber agent_id: (required)
        :return: V1NetworkRulesConnectionsPointToTagGetOneResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["agent_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_rules_connections_point_to_tag_get_one" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'agent_id' is set
        if "agent_id" not in params or params["agent_id"] is None:
            raise ValueError(
                "Missing the required parameter `agent_id` when calling `v1_network_rules_connections_point_to_tag_get_one`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "agent_id" in params:
            path_params["agent_id"] = params["agent_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/rules/connections/point-to-tag/{agent_id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkRulesConnectionsPointToTagGetOneResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_rules_connections_point_to_tag_search(
        self, body, **kwargs
    ):  # noqa: E501
        """Search point-to-tag Rules  # noqa: E501

        Gets list of point-to-tag Rules by given criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_rules_connections_point_to_tag_search(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkRulesConnectionsPointToTagSearchRequest body: Search request (required)
        :return: V1NetworkRulesConnectionsPointToTagSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_rules_connections_point_to_tag_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (
                data
            ) = self.v1_network_rules_connections_point_to_tag_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_rules_connections_point_to_tag_search_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Search point-to-tag Rules  # noqa: E501

        Gets list of point-to-tag Rules by given criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_rules_connections_point_to_tag_search_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkRulesConnectionsPointToTagSearchRequest body: Search request (required)
        :return: V1NetworkRulesConnectionsPointToTagSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_rules_connections_point_to_tag_search" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_rules_connections_point_to_tag_search`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/rules/connections/point-to-tag/search",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkRulesConnectionsPointToTagSearchResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_rules_search(self, **kwargs):  # noqa: E501
        """Search Rules  # noqa: E501

        Gets list of Rules by given criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_rules_search(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkRulesSearchRequest body:
        :return: V1NetworkRulesSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_rules_search_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.v1_network_rules_search_with_http_info(**kwargs)  # noqa: E501
            return data

    def v1_network_rules_search_with_http_info(self, **kwargs):  # noqa: E501
        """Search Rules  # noqa: E501

        Gets list of Rules by given criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_rules_search_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkRulesSearchRequest body:
        :return: V1NetworkRulesSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_rules_search" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/rules/search",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkRulesSearchResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_rules_connection_point_to_tag_remove(self, body, **kwargs):  # noqa: E501
        """Remove point-to-tag  # noqa: E501

        Removes point-to-tag Rules by given criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_rules_connection_point_to_tag_remove(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1RulesPointToTag body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_rules_connection_point_to_tag_remove_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_rules_connection_point_to_tag_remove_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_rules_connection_point_to_tag_remove_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Remove point-to-tag  # noqa: E501

        Removes point-to-tag Rules by given criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_rules_connection_point_to_tag_remove_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1RulesPointToTag body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_rules_connection_point_to_tag_remove" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_rules_connection_point_to_tag_remove`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/rules/connections/point-to-tag/remove",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Role(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "role_id": "float",
        "role_name": "str",
        "users": "list[User]",
        "user_workspaces": "list[UserWorkspace]",
        "workspace_invitations": "list[WorkspaceInvitation]",
        "permissions": "list[Permission]",
    }

    attribute_map = {
        "role_id": "role_id",
        "role_name": "role_name",
        "users": "users",
        "user_workspaces": "user_workspaces",
        "workspace_invitations": "workspace_invitations",
        "permissions": "permissions",
    }

    def __init__(
        self,
        role_id=None,
        role_name=None,
        users=None,
        user_workspaces=None,
        workspace_invitations=None,
        permissions=None,
    ):  # noqa: E501
        """Role - a model defined in Swagger"""  # noqa: E501
        self._role_id = None
        self._role_name = None
        self._users = None
        self._user_workspaces = None
        self._workspace_invitations = None
        self._permissions = None
        self.discriminator = None
        self.role_id = role_id
        self.role_name = role_name
        if users is not None:
            self.users = users
        if user_workspaces is not None:
            self.user_workspaces = user_workspaces
        if workspace_invitations is not None:
            self.workspace_invitations = workspace_invitations
        if permissions is not None:
            self.permissions = permissions

    @property
    def role_id(self):
        """Gets the role_id of this Role.  # noqa: E501


        :return: The role_id of this Role.  # noqa: E501
        :rtype: float
        """
        return self._role_id

    @role_id.setter
    def role_id(self, role_id):
        """Sets the role_id of this Role.


        :param role_id: The role_id of this Role.  # noqa: E501
        :type: float
        """
        if role_id is None:
            raise ValueError(
                "Invalid value for `role_id`, must not be `None`"
            )  # noqa: E501

        self._role_id = role_id

    @property
    def role_name(self):
        """Gets the role_name of this Role.  # noqa: E501


        :return: The role_name of this Role.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this Role.


        :param role_name: The role_name of this Role.  # noqa: E501
        :type: str
        """
        if role_name is None:
            raise ValueError(
                "Invalid value for `role_name`, must not be `None`"
            )  # noqa: E501

        self._role_name = role_name

    @property
    def users(self):
        """Gets the users of this Role.  # noqa: E501


        :return: The users of this Role.  # noqa: E501
        :rtype: list[User]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this Role.


        :param users: The users of this Role.  # noqa: E501
        :type: list[User]
        """

        self._users = users

    @property
    def user_workspaces(self):
        """Gets the user_workspaces of this Role.  # noqa: E501


        :return: The user_workspaces of this Role.  # noqa: E501
        :rtype: list[UserWorkspace]
        """
        return self._user_workspaces

    @user_workspaces.setter
    def user_workspaces(self, user_workspaces):
        """Sets the user_workspaces of this Role.


        :param user_workspaces: The user_workspaces of this Role.  # noqa: E501
        :type: list[UserWorkspace]
        """

        self._user_workspaces = user_workspaces

    @property
    def workspace_invitations(self):
        """Gets the workspace_invitations of this Role.  # noqa: E501


        :return: The workspace_invitations of this Role.  # noqa: E501
        :rtype: list[WorkspaceInvitation]
        """
        return self._workspace_invitations

    @workspace_invitations.setter
    def workspace_invitations(self, workspace_invitations):
        """Sets the workspace_invitations of this Role.


        :param workspace_invitations: The workspace_invitations of this Role.  # noqa: E501
        :type: list[WorkspaceInvitation]
        """

        self._workspace_invitations = workspace_invitations

    @property
    def permissions(self):
        """Gets the permissions of this Role.  # noqa: E501


        :return: The permissions of this Role.  # noqa: E501
        :rtype: list[Permission]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this Role.


        :param permissions: The permissions of this Role.  # noqa: E501
        :type: list[Permission]
        """

        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Role, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Role):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class V1AgentFilter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "agent_id": "list[IdNumber]",
        "agent_provider_id": "list[IdNumber]",
        "agent_tag_id": "list[IdNumber]",
        "agent_type": "list[AgentTypeParam]",
        "agent_version": "list[str]",
        "agent_tag_name": "list[str]",
        "agent_status": "list[AgentFilterAgentStatus]",
        "agent_location_country": "list[str]",
        "agent_modified_at_from": "datetime",
        "agent_modified_at_to": "datetime",
        "agent_name": "str",
    }

    attribute_map = {
        "agent_id": "agent_id",
        "agent_provider_id": "agent_provider_id",
        "agent_tag_id": "agent_tag_id",
        "agent_type": "agent_type",
        "agent_version": "agent_version",
        "agent_tag_name": "agent_tag_name",
        "agent_status": "agent_status",
        "agent_location_country": "agent_location_country",
        "agent_modified_at_from": "agent_modified_at_from",
        "agent_modified_at_to": "agent_modified_at_to",
        "agent_name": "agent_name",
    }

    def __init__(
        self,
        agent_id=None,
        agent_provider_id=None,
        agent_tag_id=None,
        agent_type=None,
        agent_version=None,
        agent_tag_name=None,
        agent_status=None,
        agent_location_country=None,
        agent_modified_at_from=None,
        agent_modified_at_to=None,
        agent_name=None,
    ):  # noqa: E501
        """V1AgentFilter - a model defined in Swagger"""  # noqa: E501
        self._agent_id = None
        self._agent_provider_id = None
        self._agent_tag_id = None
        self._agent_type = None
        self._agent_version = None
        self._agent_tag_name = None
        self._agent_status = None
        self._agent_location_country = None
        self._agent_modified_at_from = None
        self._agent_modified_at_to = None
        self._agent_name = None
        self.discriminator = None
        if agent_id is not None:
            self.agent_id = agent_id
        if agent_provider_id is not None:
            self.agent_provider_id = agent_provider_id
        if agent_tag_id is not None:
            self.agent_tag_id = agent_tag_id
        if agent_type is not None:
            self.agent_type = agent_type
        if agent_version is not None:
            self.agent_version = agent_version
        if agent_tag_name is not None:
            self.agent_tag_name = agent_tag_name
        if agent_status is not None:
            self.agent_status = agent_status
        if agent_location_country is not None:
            self.agent_location_country = agent_location_country
        if agent_modified_at_from is not None:
            self.agent_modified_at_from = agent_modified_at_from
        if agent_modified_at_to is not None:
            self.agent_modified_at_to = agent_modified_at_to
        if agent_name is not None:
            self.agent_name = agent_name

    @property
    def agent_id(self):
        """Gets the agent_id of this V1AgentFilter.  # noqa: E501


        :return: The agent_id of this V1AgentFilter.  # noqa: E501
        :rtype: list[IdNumber]
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """Sets the agent_id of this V1AgentFilter.


        :param agent_id: The agent_id of this V1AgentFilter.  # noqa: E501
        :type: list[IdNumber]
        """

        self._agent_id = agent_id

    @property
    def agent_provider_id(self):
        """Gets the agent_provider_id of this V1AgentFilter.  # noqa: E501


        :return: The agent_provider_id of this V1AgentFilter.  # noqa: E501
        :rtype: list[IdNumber]
        """
        return self._agent_provider_id

    @agent_provider_id.setter
    def agent_provider_id(self, agent_provider_id):
        """Sets the agent_provider_id of this V1AgentFilter.


        :param agent_provider_id: The agent_provider_id of this V1AgentFilter.  # noqa: E501
        :type: list[IdNumber]
        """

        self._agent_provider_id = agent_provider_id

    @property
    def agent_tag_id(self):
        """Gets the agent_tag_id of this V1AgentFilter.  # noqa: E501


        :return: The agent_tag_id of this V1AgentFilter.  # noqa: E501
        :rtype: list[IdNumber]
        """
        return self._agent_tag_id

    @agent_tag_id.setter
    def agent_tag_id(self, agent_tag_id):
        """Sets the agent_tag_id of this V1AgentFilter.


        :param agent_tag_id: The agent_tag_id of this V1AgentFilter.  # noqa: E501
        :type: list[IdNumber]
        """

        self._agent_tag_id = agent_tag_id

    @property
    def agent_type(self):
        """Gets the agent_type of this V1AgentFilter.  # noqa: E501


        :return: The agent_type of this V1AgentFilter.  # noqa: E501
        :rtype: list[AgentTypeParam]
        """
        return self._agent_type

    @agent_type.setter
    def agent_type(self, agent_type):
        """Sets the agent_type of this V1AgentFilter.


        :param agent_type: The agent_type of this V1AgentFilter.  # noqa: E501
        :type: list[AgentTypeParam]
        """

        self._agent_type = agent_type

    @property
    def agent_version(self):
        """Gets the agent_version of this V1AgentFilter.  # noqa: E501


        :return: The agent_version of this V1AgentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._agent_version

    @agent_version.setter
    def agent_version(self, agent_version):
        """Sets the agent_version of this V1AgentFilter.


        :param agent_version: The agent_version of this V1AgentFilter.  # noqa: E501
        :type: list[str]
        """

        self._agent_version = agent_version

    @property
    def agent_tag_name(self):
        """Gets the agent_tag_name of this V1AgentFilter.  # noqa: E501


        :return: The agent_tag_name of this V1AgentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._agent_tag_name

    @agent_tag_name.setter
    def agent_tag_name(self, agent_tag_name):
        """Sets the agent_tag_name of this V1AgentFilter.


        :param agent_tag_name: The agent_tag_name of this V1AgentFilter.  # noqa: E501
        :type: list[str]
        """

        self._agent_tag_name = agent_tag_name

    @property
    def agent_status(self):
        """Gets the agent_status of this V1AgentFilter.  # noqa: E501


        :return: The agent_status of this V1AgentFilter.  # noqa: E501
        :rtype: list[AgentFilterAgentStatus]
        """
        return self._agent_status

    @agent_status.setter
    def agent_status(self, agent_status):
        """Sets the agent_status of this V1AgentFilter.


        :param agent_status: The agent_status of this V1AgentFilter.  # noqa: E501
        :type: list[AgentFilterAgentStatus]
        """

        self._agent_status = agent_status

    @property
    def agent_location_country(self):
        """Gets the agent_location_country of this V1AgentFilter.  # noqa: E501


        :return: The agent_location_country of this V1AgentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._agent_location_country

    @agent_location_country.setter
    def agent_location_country(self, agent_location_country):
        """Sets the agent_location_country of this V1AgentFilter.


        :param agent_location_country: The agent_location_country of this V1AgentFilter.  # noqa: E501
        :type: list[str]
        """

        self._agent_location_country = agent_location_country

    @property
    def agent_modified_at_from(self):
        """Gets the agent_modified_at_from of this V1AgentFilter.  # noqa: E501


        :return: The agent_modified_at_from of this V1AgentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._agent_modified_at_from

    @agent_modified_at_from.setter
    def agent_modified_at_from(self, agent_modified_at_from):
        """Sets the agent_modified_at_from of this V1AgentFilter.


        :param agent_modified_at_from: The agent_modified_at_from of this V1AgentFilter.  # noqa: E501
        :type: datetime
        """

        self._agent_modified_at_from = agent_modified_at_from

    @property
    def agent_modified_at_to(self):
        """Gets the agent_modified_at_to of this V1AgentFilter.  # noqa: E501


        :return: The agent_modified_at_to of this V1AgentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._agent_modified_at_to

    @agent_modified_at_to.setter
    def agent_modified_at_to(self, agent_modified_at_to):
        """Sets the agent_modified_at_to of this V1AgentFilter.


        :param agent_modified_at_to: The agent_modified_at_to of this V1AgentFilter.  # noqa: E501
        :type: datetime
        """

        self._agent_modified_at_to = agent_modified_at_to

    @property
    def agent_name(self):
        """Gets the agent_name of this V1AgentFilter.  # noqa: E501


        :return: The agent_name of this V1AgentFilter.  # noqa: E501
        :rtype: str
        """
        return self._agent_name

    @agent_name.setter
    def agent_name(self, agent_name):
        """Sets the agent_name of this V1AgentFilter.


        :param agent_name: The agent_name of this V1AgentFilter.  # noqa: E501
        :type: str
        """

        self._agent_name = agent_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1AgentFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1AgentFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from syntropy_sdk.api_client import ApiClient


class AnalyticsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def v1_network_a_bandwidth_get(
        self, agent_src_id, agent_dst_id, _from, to, **kwargs
    ):  # noqa: E501
        """Get bandwidth  # noqa: E501

        Retrieves Connections bandwidth information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_a_bandwidth_get(agent_src_id, agent_dst_id, _from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdNumber agent_src_id: Source Agent Id (required)
        :param IdNumber agent_dst_id: Destination Agent Id (required)
        :param datetime _from: (required)
        :param datetime to: (required)
        :return: ADataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_a_bandwidth_get_with_http_info(
                agent_src_id, agent_dst_id, _from, to, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_a_bandwidth_get_with_http_info(
                agent_src_id, agent_dst_id, _from, to, **kwargs
            )  # noqa: E501
            return data

    def v1_network_a_bandwidth_get_with_http_info(
        self, agent_src_id, agent_dst_id, _from, to, **kwargs
    ):  # noqa: E501
        """Get bandwidth  # noqa: E501

        Retrieves Connections bandwidth information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_a_bandwidth_get_with_http_info(agent_src_id, agent_dst_id, _from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdNumber agent_src_id: Source Agent Id (required)
        :param IdNumber agent_dst_id: Destination Agent Id (required)
        :param datetime _from: (required)
        :param datetime to: (required)
        :return: ADataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["agent_src_id", "agent_dst_id", "_from", "to"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_a_bandwidth_get" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'agent_src_id' is set
        if "agent_src_id" not in params or params["agent_src_id"] is None:
            raise ValueError(
                "Missing the required parameter `agent_src_id` when calling `v1_network_a_bandwidth_get`"
            )  # noqa: E501
        # verify the required parameter 'agent_dst_id' is set
        if "agent_dst_id" not in params or params["agent_dst_id"] is None:
            raise ValueError(
                "Missing the required parameter `agent_dst_id` when calling `v1_network_a_bandwidth_get`"
            )  # noqa: E501
        # verify the required parameter '_from' is set
        if "_from" not in params or params["_from"] is None:
            raise ValueError(
                "Missing the required parameter `_from` when calling `v1_network_a_bandwidth_get`"
            )  # noqa: E501
        # verify the required parameter 'to' is set
        if "to" not in params or params["to"] is None:
            raise ValueError(
                "Missing the required parameter `to` when calling `v1_network_a_bandwidth_get`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if "agent_src_id" in params:
            query_params.append(("agent_src_id", params["agent_src_id"]))  # noqa: E501
        if "agent_dst_id" in params:
            query_params.append(("agent_dst_id", params["agent_dst_id"]))  # noqa: E501
        if "_from" in params:
            query_params.append(("from", params["_from"]))  # noqa: E501
        if "to" in params:
            query_params.append(("to", params["to"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/a/bandwidth",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ADataResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_a_iface_active_change_get(
        self, agent_src_id, agent_dst_id, _from, to, **kwargs
    ):  # noqa: E501
        """Get active iface changes  # noqa: E501

        Retrieves active iface changes data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_a_iface_active_change_get(agent_src_id, agent_dst_id, _from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int agent_src_id: Source Agent Id (required)
        :param int agent_dst_id: Destination Agent Id (required)
        :param datetime _from: (required)
        :param datetime to: (required)
        :return: ADataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_a_iface_active_change_get_with_http_info(
                agent_src_id, agent_dst_id, _from, to, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_a_iface_active_change_get_with_http_info(
                agent_src_id, agent_dst_id, _from, to, **kwargs
            )  # noqa: E501
            return data

    def v1_network_a_iface_active_change_get_with_http_info(
        self, agent_src_id, agent_dst_id, _from, to, **kwargs
    ):  # noqa: E501
        """Get active iface changes  # noqa: E501

        Retrieves active iface changes data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_a_iface_active_change_get_with_http_info(agent_src_id, agent_dst_id, _from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int agent_src_id: Source Agent Id (required)
        :param int agent_dst_id: Destination Agent Id (required)
        :param datetime _from: (required)
        :param datetime to: (required)
        :return: ADataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["agent_src_id", "agent_dst_id", "_from", "to"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_a_iface_active_change_get" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'agent_src_id' is set
        if "agent_src_id" not in params or params["agent_src_id"] is None:
            raise ValueError(
                "Missing the required parameter `agent_src_id` when calling `v1_network_a_iface_active_change_get`"
            )  # noqa: E501
        # verify the required parameter 'agent_dst_id' is set
        if "agent_dst_id" not in params or params["agent_dst_id"] is None:
            raise ValueError(
                "Missing the required parameter `agent_dst_id` when calling `v1_network_a_iface_active_change_get`"
            )  # noqa: E501
        # verify the required parameter '_from' is set
        if "_from" not in params or params["_from"] is None:
            raise ValueError(
                "Missing the required parameter `_from` when calling `v1_network_a_iface_active_change_get`"
            )  # noqa: E501
        # verify the required parameter 'to' is set
        if "to" not in params or params["to"] is None:
            raise ValueError(
                "Missing the required parameter `to` when calling `v1_network_a_iface_active_change_get`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if "agent_src_id" in params:
            query_params.append(("agent_src_id", params["agent_src_id"]))  # noqa: E501
        if "agent_dst_id" in params:
            query_params.append(("agent_dst_id", params["agent_dst_id"]))  # noqa: E501
        if "_from" in params:
            query_params.append(("from", params["_from"]))  # noqa: E501
        if "to" in params:
            query_params.append(("to", params["to"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/a/iface-active-change",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ADataResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_a_latency_get(
        self, agent_src_id, agent_dst_id, _from, to, **kwargs
    ):  # noqa: E501
        """Get latency  # noqa: E501

        Retrieves Connections latency.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_a_latency_get(agent_src_id, agent_dst_id, _from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int agent_src_id: Source Agent Id (required)
        :param int agent_dst_id: Destination Agent Id (required)
        :param datetime _from: (required)
        :param datetime to: (required)
        :return: ADataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_a_latency_get_with_http_info(
                agent_src_id, agent_dst_id, _from, to, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_a_latency_get_with_http_info(
                agent_src_id, agent_dst_id, _from, to, **kwargs
            )  # noqa: E501
            return data

    def v1_network_a_latency_get_with_http_info(
        self, agent_src_id, agent_dst_id, _from, to, **kwargs
    ):  # noqa: E501
        """Get latency  # noqa: E501

        Retrieves Connections latency.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_a_latency_get_with_http_info(agent_src_id, agent_dst_id, _from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int agent_src_id: Source Agent Id (required)
        :param int agent_dst_id: Destination Agent Id (required)
        :param datetime _from: (required)
        :param datetime to: (required)
        :return: ADataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["agent_src_id", "agent_dst_id", "_from", "to"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_a_latency_get" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'agent_src_id' is set
        if "agent_src_id" not in params or params["agent_src_id"] is None:
            raise ValueError(
                "Missing the required parameter `agent_src_id` when calling `v1_network_a_latency_get`"
            )  # noqa: E501
        # verify the required parameter 'agent_dst_id' is set
        if "agent_dst_id" not in params or params["agent_dst_id"] is None:
            raise ValueError(
                "Missing the required parameter `agent_dst_id` when calling `v1_network_a_latency_get`"
            )  # noqa: E501
        # verify the required parameter '_from' is set
        if "_from" not in params or params["_from"] is None:
            raise ValueError(
                "Missing the required parameter `_from` when calling `v1_network_a_latency_get`"
            )  # noqa: E501
        # verify the required parameter 'to' is set
        if "to" not in params or params["to"] is None:
            raise ValueError(
                "Missing the required parameter `to` when calling `v1_network_a_latency_get`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if "agent_src_id" in params:
            query_params.append(("agent_src_id", params["agent_src_id"]))  # noqa: E501
        if "agent_dst_id" in params:
            query_params.append(("agent_dst_id", params["agent_dst_id"]))  # noqa: E501
        if "_from" in params:
            query_params.append(("from", params["_from"]))  # noqa: E501
        if "to" in params:
            query_params.append(("to", params["to"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/a/latency",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ADataResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_a_packet_loss_get(
        self, agent_src_id, agent_dst_id, _from, to, **kwargs
    ):  # noqa: E501
        """Get packet loss  # noqa: E501

        Retrieves Connections packet loss.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_a_packet_loss_get(agent_src_id, agent_dst_id, _from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int agent_src_id: Source Agent Id (required)
        :param int agent_dst_id: Destination Agent Id (required)
        :param datetime _from: (required)
        :param datetime to: (required)
        :return: ADataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_a_packet_loss_get_with_http_info(
                agent_src_id, agent_dst_id, _from, to, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_a_packet_loss_get_with_http_info(
                agent_src_id, agent_dst_id, _from, to, **kwargs
            )  # noqa: E501
            return data

    def v1_network_a_packet_loss_get_with_http_info(
        self, agent_src_id, agent_dst_id, _from, to, **kwargs
    ):  # noqa: E501
        """Get packet loss  # noqa: E501

        Retrieves Connections packet loss.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_a_packet_loss_get_with_http_info(agent_src_id, agent_dst_id, _from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int agent_src_id: Source Agent Id (required)
        :param int agent_dst_id: Destination Agent Id (required)
        :param datetime _from: (required)
        :param datetime to: (required)
        :return: ADataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["agent_src_id", "agent_dst_id", "_from", "to"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_a_packet_loss_get" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'agent_src_id' is set
        if "agent_src_id" not in params or params["agent_src_id"] is None:
            raise ValueError(
                "Missing the required parameter `agent_src_id` when calling `v1_network_a_packet_loss_get`"
            )  # noqa: E501
        # verify the required parameter 'agent_dst_id' is set
        if "agent_dst_id" not in params or params["agent_dst_id"] is None:
            raise ValueError(
                "Missing the required parameter `agent_dst_id` when calling `v1_network_a_packet_loss_get`"
            )  # noqa: E501
        # verify the required parameter '_from' is set
        if "_from" not in params or params["_from"] is None:
            raise ValueError(
                "Missing the required parameter `_from` when calling `v1_network_a_packet_loss_get`"
            )  # noqa: E501
        # verify the required parameter 'to' is set
        if "to" not in params or params["to"] is None:
            raise ValueError(
                "Missing the required parameter `to` when calling `v1_network_a_packet_loss_get`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if "agent_src_id" in params:
            query_params.append(("agent_src_id", params["agent_src_id"]))  # noqa: E501
        if "agent_dst_id" in params:
            query_params.append(("agent_dst_id", params["agent_dst_id"]))  # noqa: E501
        if "_from" in params:
            query_params.append(("from", params["_from"]))  # noqa: E501
        if "to" in params:
            query_params.append(("to", params["to"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/a/packet-loss",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ADataResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_a_statuses_search(self, body, **kwargs):  # noqa: E501
        """Search statuses  # noqa: E501

        Retrieve Connection statuses by given criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_a_statuses_search(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAStatusesSearchRequest body: (required)
        :return: V1NetworkAStatusesSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_a_statuses_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_a_statuses_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_a_statuses_search_with_http_info(self, body, **kwargs):  # noqa: E501
        """Search statuses  # noqa: E501

        Retrieve Connection statuses by given criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_a_statuses_search_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAStatusesSearchRequest body: (required)
        :return: V1NetworkAStatusesSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_a_statuses_search" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_a_statuses_search`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/a/statuses/search",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAStatusesSearchResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_a_statuses_warnings_search(self, body, **kwargs):  # noqa: E501
        """Search status warnings  # noqa: E501

        Retrieves status warnings by given criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_a_statuses_warnings_search(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAStatusesWarningsSearchRequest body: (required)
        :return: V1NetworkAStatusesWarningsSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_a_statuses_warnings_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_a_statuses_warnings_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_a_statuses_warnings_search_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Search status warnings  # noqa: E501

        Retrieves status warnings by given criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_a_statuses_warnings_search_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAStatusesWarningsSearchRequest body: (required)
        :return: V1NetworkAStatusesWarningsSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_a_statuses_warnings_search" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_a_statuses_warnings_search`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/a/statuses/warnings/search",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAStatusesWarningsSearchResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )
